from setuptools import setup, find_packages

setup(
    name = 'developmental_index',
    version = '1.0',
    author = 'Ben Devlin',
    author_email = 'bad36@duke.edu',
    packages = find_packages('numpy', 'pandas', 'scipy')

)